<?php

namespace Drupal\datafield\Plugin\DataField\FieldFormatter;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\datafield\Plugin\DataFieldFormatterInterface;

/**
 * Plugin implementation of the 'entity reference rendered entity' formatter.
 *
 * @FieldFormatter(
 *   id = "entity_reference_entity_view",
 *   label = @Translation("Rendered entity"),
 *   description = @Translation("Display the referenced entities rendered by entity_view()."),
 *   field_types = {
 *     "entity_reference"
 *   }
 * )
 */
class EntityReferenceEntityFormatter implements DataFieldFormatterInterface {

  use StringTranslationTrait;
  /**
   * The number of times this formatter allows rendering the same entity.
   *
   * @var int
   */
  const RECURSIVE_RENDER_LIMIT = 20;

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'view_mode' => 'default',
      'link' => FALSE,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $settings = $form['#settings'];

    $extract = explode(':', $form["#field_settings"]["entity_reference_type"]);
    $entityDisplayRepository = \Drupal::service('entity_display.repository');
    $options = $entityDisplayRepository->getViewModeOptions(end($extract));

    $elements['view_mode'] = [
      '#type' => 'select',
      '#options' => $options,
      '#title' => $this->t('View mode'),
      '#default_value' => $settings['view_mode'] ?? self::defaultSettings()['view_mode'],
    ];

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary($settings = []) {
    $summary = [];
    $view_mode = $settings['view_mode'] ?? '';
    $summary[] = $this->t('Rendered as @mode', ['@mode' => $view_mode]);

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements($item, $langcode) {
    $view_mode = !empty($item->settings['view_mode']) ? $item->settings['view_mode'] : 'full';
    $entity_reference_type = $item->field_setting["entity_reference_type"] ?? '';
    $explode = explode(':', $entity_reference_type);
    $entityTypeManager = \Drupal::entityTypeManager();
    $reference_type = end($explode);
    if (empty($reference_type) || empty($item->value)) {
      return $item->value;
    }
    $entity = $entityTypeManager->getStorage($reference_type)->load($item->value);
    if (empty($entity)) {
      return $item->value;
    }
    $view_builder = $entityTypeManager->getViewBuilder($reference_type);
    return $view_builder->view($entity, $view_mode);

  }

}
