<?php

namespace Drupal\datafield\Plugin\DataField\FieldFormatter;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\datafield\Plugin\DataFieldFormatterInterface;

/**
 * Plugin implementation of the 'entity reference label' formatter.
 *
 * @FieldFormatter(
 *   id = "entity_reference_label",
 *   label = @Translation("Label"),
 *   description = @Translation("Display the label of the referenced entities."),
 *   field_types = {
 *     "entity_reference",
 *   }
 * )
 */
class EntityReferenceLabelFormatter implements DataFieldFormatterInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'link' => TRUE,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $settings = $form['#settings'];
    $elements['link'] = [
      '#title' => $this->t('Link label to the referenced entity'),
      '#type' => 'checkbox',
      '#default_value' => $settings['link'] ?? TRUE,
    ];

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary($settings = []) {
    $summary = [];
    $summary[] = !empty($settings['link']) ? $this->t('Link to the referenced entity') : $this->t('No link');
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements($item, $langcode) {
    if (empty($item->value)) {
      return $item->value;
    }
    $explode = explode(':', $item->field_setting["entity_reference_type"]);
    $reference_type = end($explode);
    $entity_id = $item->value;
    $entity = \Drupal::entityTypeManager()
      ->getStorage($reference_type)
      ->load($entity_id);
    if (empty($entity)) {
      return '';
    }
    if (!empty($item->settings["link"])) {
      return [
        '#type' => 'link',
        '#langcode' => $langcode,
        '#title' => $entity->label(),
        '#url' => $entity->toUrl(),
        '#cache' => ['tags' => $entity->getCacheTags()],
      ];
    }
    else {
      return [
        '#plain_text' => $entity->label(),
        '#langcode' => $langcode,
        '#cache' => ['tags' => $entity->getCacheTags()],
      ];
    }
  }

}
