<?php

namespace Drupal\datafield\Plugin\DataField\FieldFormatter;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\datafield\Plugin\DataFieldFormatterInterface;

/**
 * Plugin implementation of the 'file_table' formatter.
 *
 * @FieldFormatter(
 *   id = "file_table",
 *   label = @Translation("Table of files"),
 *   field_types = {
 *     "file"
 *   }
 * )
 */
class TableFileFormatter implements DataFieldFormatterInterface {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function viewElements($item, $langcode) {
    $elements = [];

    $fid = $item->value;
    if (!is_numeric($fid)) {
      return $item->value;
    }
    $entity_type_manager = \Drupal::service('entity_type.manager');
    $file = $entity_type_manager->getStorage('file')->load($fid);
    $header = [$this->t('Attachment'), $this->t('Size')];
    $rows[] = [
      [
        'data' => [
          '#theme' => 'file_link',
          '#file' => $file,
          '#cache' => ['tags' => $file->getCacheTags()],
        ],
      ],
      ['data' => format_size($file->getSize())],
    ];
    if (!empty($rows)) {
      return [
        '#theme' => 'table__file_formatter_table',
        '#header' => $header,
        '#rows' => $rows,
      ];
    }

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $settings = $form['#settings'];
    $element['file_download_path'] = [
      '#title' => $this->t('Display the file download URI'),
      '#type' => 'checkbox',
      '#default_value' => $settings['file_download_path'] ?? FALSE,
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary($settings = []) {
    $summary = [];
    if (!empty($settings['file_download_path'])) {
      $summary[] = $this->t('Link formatting table');
    }
    return $summary;
  }

}
