<?php

namespace Drupal\datafield\Plugin\DataField\FieldFormatter;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Url;
use Drupal\datafield\Plugin\DataFieldFormatterInterface;

/**
 * Plugin implementation of the 'uri_link' formatter.
 *
 * @FieldFormatter(
 *   id = "uri_link",
 *   label = @Translation("Link to URI"),
 *   field_types = {
 *     "uri",
 *     "string",
 *   }
 * )
 */
class UriLinkFormatter implements DataFieldFormatterInterface {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function viewElements($item, $langcode) {
    if (empty($item->value)) {
      return $item->value;
    }
    if (is_numeric($item->value)) {
      $entity_type = 'node';
      $entity = \Drupal::entityTypeManager()
        ->getStorage($entity_type)
        ->load($item->value);
      $url = $entity->toUrl()->toString();
      $title = $entity->label();
      return [
        '#type' => 'link',
        '#url' => $url,
        '#title' => $title,
      ];
    }
    else {
      $url = Url::fromUri($item->value);
      return [
        '#type' => 'link',
        '#url' => $url,
        '#title' => $item->value,
      ];
    }
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary($settings = []) {
    return [];
  }

}
