<?php

namespace Drupal\datafield\Plugin\DataField\FieldFormatter;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\datafield\Plugin\DataFieldFormatterInterface;

/**
 * Plugin implementation of the 'file_url_plain' formatter.
 *
 * @FieldFormatter(
 *   id = "file_url_plain",
 *   label = @Translation("URL to file"),
 *   field_types = {
 *     "file"
 *   }
 * )
 */
class UrlPlainFormatter implements DataFieldFormatterInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function viewElements($item, $langcode) {
    $fid = $item->value;
    if (!is_numeric($item->value)) {
      return $item->value;
    }
    $entity_type_manager = \Drupal::service('entity_type.manager');
    $file = $entity_type_manager->getStorage('file')->load($fid);
    if (empty($file)) {
      return '';
    }
    return [
      '#markup' => $file->createFileUrl(),
      '#cache' => ['tags' => $file->getCacheTags()],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    return [];
  }

}
