<?php

namespace Drupal\datafield\Plugin\DataField\FieldType;

use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Defines the 'file' field type.
 *
 * @DataFieldType(
 *   id = "file",
 *   label = @Translation("File"),
 *   description = @Translation("A field file/image value."),
 *   category = @Translation("Text"),
 *   default_widget = "managed_file",
 *   default_formatter = "file_uri",
 * )
 */
class FileItem extends IntegerItem {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function defaultStorageSettings() {
    return [
      'unsigned' => FALSE,
      // Valid size property values include: 'tiny', 'small', 'medium', 'normal'
      // and 'big'.
      'size' => 'normal',
      'type' => 'int',
      'not null' => FALSE,
      'file_extensions' => 'jpg jpeg gif png txt doc xls pdf ppt pps odt ods odp',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getLabel() {
    return $this->t('File');
  }

  /**
   * {@inheritdoc}
   */
  public function fieldSettingsForm(array $field_settings, array $settings) {
    $directoryDefault = str_replace('field_', '', $field_settings["field_name"]) . '-' . $settings["name"];
    $field_form = [
      'label' => [
        '#type' => 'textfield',
        '#title' => $this->t('Label'),
        '#default_value' => $field_settings['label'] ?? ucfirst($settings["name"]),
      ],
      'required' => [
        '#type' => 'checkbox',
        '#title' => $this->t('Required'),
        '#default_value' => $field_settings['required'] ?? FALSE,
      ],
      'file_directory' => [
        '#type' => 'textfield',
        '#title' => $this->t('File directory'),
        '#default_value' => $field_settings['file_directory'] ?? $directoryDefault,
        '#description' => $this->t('Optional subdirectory within the upload destination where files will be stored. Do not include preceding or trailing slashes.'),
        // '#element_validate' => [[static::class, 'validateDirectory']],
      ],
      'file_extensions' => [
        '#type' => 'textfield',
        '#title' => $this->t('Allowed file extensions'),
        '#default_value' => $field_settings['file_extensions'] ?? self::defaultStorageSettings()['file_extensions'],
        '#description' => $this->t("Separate extensions with a comma or space. Each extension can contain alphanumeric characters, '.', and '_', and should start and end with an alphanumeric character."),
        '#maxlength' => 256,
        '#required' => TRUE,
      ],
    ];
    return $field_form;
  }

  /**
   * Get constraints.
   *
   * {@inheritdoc}
   */
  public function getConstraints(array $settings) {
    $constraints = [];
    if ($settings['required']) {
      $constraints['NotBlank'] = [];
    }
    return $constraints;
  }

}
