<?php

namespace Drupal\datafield\Plugin\DataField\FieldType;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\datafield\Plugin\DataFieldTypeInterface;

/**
 * Defines the 'serial' entity field type.
 *
 * @DataFieldType(
 *   id = "serial",
 *   label = @Translation("Serial"),
 *   description = @Translation("An entity field containing a serial."),
 *   no_ui = TRUE,
 *   default_widget = "textfield",
 *   default_formatter = "string"
 * )
 */
class SerialItem implements DataFieldTypeInterface {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function defaultStorageSettings() {
    return [
      'type' => 'serial',
      'size' => 'normal',
      'serialize' => TRUE,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(array $settings) {
    $default = self::defaultStorageSettings();
    if (!empty($settings['size'])) {
      $default['size'] = $settings['size'];
    }
    if (!empty($settings['unsigned'])) {
      $default['unsigned'] = $settings['unsigned'];
    }
    return [
      'columns' => [
        'value' => $default,
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getLabel() {
    return $this->t('Serial');
  }

  /**
   * {@inheritdoc}
   */
  public static function generateSampleValue() {
    $min = 0;
    $max = 999;
    $values['value'] = mt_rand($min, $max);
    return $values;
  }

  /**
   * {@inheritdoc}
   */
  public function fieldSettingsForm(array $field_settings, array $settings) {
    $field_form = [
      'label' => [
        '#type' => 'textfield',
        '#title' => $this->t('Label'),
        '#default_value' => $field_settings['label'],
      ],
    ];
    return $field_form;
  }

  /**
   * {@inheritdoc}
   */
  public function getConstraints(array $settings) {
    $constraints = [];
    if ($settings['required']) {
      $constraints['NotBlank'] = [];
    }
    return $constraints;
  }

  /**
   * {@inheritdoc}
   */
  public function getPluginId() {
    // @todo Implement getPluginId() method.
  }

  /**
   * {@inheritdoc}
   */
  public function getPluginDefinition() {
    // @todo Implement getPluginDefinition() method.
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(array $settings) {
    // @todo Implement propertyDefinitions() method.
  }

}
