<?php

namespace Drupal\datafield\Plugin\DataField\FieldWidget;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\datafield\Plugin\DataFieldWidgetInterface;

/**
 * Plugin implementation of the 'entity_reference_autocomplete_tags' widget.
 *
 * @FieldWidget(
 *   id = "entity_reference_autocomplete_tags",
 *   label = @Translation("Autocomplete (Tags style)"),
 *   description = @Translation("An autocomplete text field with tagging support."),
 *   field_types = {
 *     "entity_reference"
 *   }
 * )
 */
class EntityReferenceAutocompleteTagsWidget implements DataFieldWidgetInterface {

  use StringTranslationTrait;

  /**
   * Get form element.
   *
   * {@inheritdoc}
   */
  public function getFormElement(&$element, $item, $setting) {
    $element['#type'] = 'entity_autocomplete';
    $element['#tag'] = TRUE;
    $element['#maxlength'] = 1024;
    $element['#placeholder'] = implode(' ', [
      $this->t('Typing'),
      $element["#field_settings"]["label"],
    ]);
    if (isset($element["#default_value"]) && is_numeric($element["#default_value"])) {
      $entity = \Drupal::entityTypeManager()
        ->getStorage($element["#entity_type"])
        ->load($element["#default_value"]);
      $element["#default_value"] = $entity;
    }
  }

}
