<?php

namespace Drupal\datafield\Plugin\DataField\FieldWidget;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\datafield\Plugin\DataFieldWidgetInterface;
use Drupal\node\NodeInterface;
use Drupal\taxonomy\TermInterface;
use Drupal\user\UserInterface;

/**
 * Plugin implementation of the 'entity_reference_autocomplete' widget.
 *
 * @FieldWidget(
 *   id = "entity_reference_autocomplete",
 *   label = @Translation("Autocomplete"),
 *   description = @Translation("An autocomplete text field."),
 *   field_types = {
 *     "entity_reference"
 *   }
 * )
 */
class EntityReferenceAutocompleteWidget implements DataFieldWidgetInterface {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function getFormElement(&$element, $item, $setting) {
    $element['#type'] = 'entity_autocomplete';
    $element['#tag'] = FALSE;
    $element['#maxlength'] = 1024;
    $element['#placeholder'] = implode(' ', [
      $this->t('Typing'),
      $element["#field_settings"]["label"] ?? '',
    ]);
    if (isset($element["#default_value"]) && is_numeric($element["#default_value"])) {
      $entity = \Drupal::entityTypeManager()
        ->getStorage($element["#entity_type"])
        ->load($element["#default_value"]);
      $element["#default_value"] = $entity;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues($value, array $form, FormStateInterface $form_state) {
    if (isset($value["entity"]) && !empty($form["#value_origin"])) {
      $entity = $value["entity"] ?? $value;
      if ($entity instanceof NodeInterface) {
        $entity->setTitle($form['#value_origin']);
        $entity->save();
        return $entity->id();
      }
      if ($entity instanceof UserInterface) {
        $name = $form['#value_origin'] ?? '';
        $entity->setUsername($name);
        $entity->activate();
        $host = \Drupal::request()->getHost();
        $email = preg_replace('~&([a-z]{1,2})(acute|cedil|circ|grave|lig|orn|ring|slash|th|tilde|uml);~i', '$1', htmlentities($name, ENT_QUOTES, 'UTF-8'));
        $email = str_replace(' ', '.', $email) . '@' . $host;
        $entity->setEmail($email);
        $entity->save();
        return $entity->id();
      }
      if ($entity instanceof TermInterface) {
        $entity->setName($form['#value_origin']);
        $entity->save();
        return $entity->id();
      }
    }
    return $value;
  }

}
