<?php

namespace Drupal\datafield\Plugin\DataField\FieldWidget;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\datafield\Plugin\DataFieldWidgetInterface;

/**
 * Plugin implementation of the 'file_generic' widget.
 *
 * @FieldWidget(
 *   id = "managed_file",
 *   label = @Translation("Uploading and saving file"),
 *   field_types = {
 *     "file",
 *     "entity_reference",
 *   },
 * )
 */
class FileWidget implements DataFieldWidgetInterface {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function getFormElement(&$element, $item = NULL, $setting = []) {
    $fieldName = str_replace('field_', '', $element['#field_name']);
    $element['#upload_location'] = 'public://' . $fieldName . '/';
    if (!empty($element["#default_value"]) && !is_array($element["#default_value"])) {
      $element["#default_value"] = [$element["#default_value"]];
    }
    if (!empty($element["#field_settings"]["file_directory"])) {
      $element['#upload_location'] = 'public://' . $element["#field_settings"]["file_directory"] . '/';
    }
    if (!empty($element["#field_settings"]["file_extensions"])) {
      $setting["file_extensions"] = str_replace(
        [',', '  '], ' ',
        $element["#field_settings"]["file_extensions"]
      );
      $element['#upload_validators'] = [
        'file_validate_extensions' => [$setting["file_extensions"]],
      ];
    }
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues($value, array $form, FormStateInterface $form_state) {
    $entityType = $form["#field_settings"]["entity_reference_type"] ?? 'file';
    $checkEntityFile = in_array($entityType, ['file', 'image']);
    if ($checkEntityFile && is_array($value)) {
      return current($value);
    }
    return $value;
  }

}
