<?php

namespace Drupal\datafield\Plugin\DataField\FieldWidget;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Url;
use Drupal\datafield\Plugin\DataFieldWidgetInterface;

/**
 * Plugin implementation of the 'entity_reference' widget.
 *
 * @FieldWidget(
 *   id = "hierarchical_select",
 *   label = @Translation("Hierarchical select"),
 *   field_types = {
 *     "entity_reference"
 *   },
 *   bundle = "taxonomy_term"
 * )
 */
class HierarchicalSelectWidget implements DataFieldWidgetInterface {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function getFormElement(&$element, $item = NULL, $setting = []) {
    $element['#type'] = 'hidden';
    $hierarchical_select = [];
    $default_value = $element["#default_value"] ?? '';
    if (!empty($default_value)) {
      $parents = \Drupal::service('entity_type.manager')->getStorage('taxonomy_term')
        ->loadAllParents($default_value);
      if (!empty($parents)) {
        $parentsTerms = array_keys($parents);
        $parentsTerms = array_reverse($parentsTerms);
        $element['#attributes']['data-parents'] = implode('-', $parentsTerms);
      }
    }
    $element['#attributes']['data-vocabulary'] = $element['#field_settings']['target_bundles'];
    $element['#attributes']['class'][] = 'hierarchical_select';
    if (!empty($bundle = $element["#bundle"]) && empty($hierarchical_select[$bundle])) {
      $element['#attached']['library'] = ['datafield/hierarchical_select'];
      $hierarchical_select[$bundle] = $this->getTaxonomyParent($bundle);
      $element['#attached']['drupalSettings']['datafieldHierarchicalSelect'][$bundle] = [$hierarchical_select[$bundle]];
      $url = Url::fromRoute('datafield.hierarchical', ['vocabulary' => $bundle], ['absolute' => TRUE])
        ->toString();
      $element['#attached']['drupalSettings']['datafieldHierarchicalAjax'][$bundle] = $url;
    }
  }

  /**
   * Get taxonomy by parent.
   *
   * @param mixed $vocabulary
   *   Taxnomy vocabulary.
   * @param int $parent
   *   Parent term id.
   *
   * @return array
   *   List taxonomy by parent.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  private function getTaxonomyParent(mixed $vocabulary, int $parent = 0): array {
    $tree = [];
    $terms = \Drupal::service('entity_type.manager')->getStorage('taxonomy_term')->loadTree($vocabulary, $parent, 1, TRUE);
    foreach ($terms as $term) {
      $tree[$term->id()] = $term->getName();
    }
    return $tree;
  }

}
