<?php

namespace Drupal\datafield\Plugin\DataField\FieldWidget;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\datafield\Plugin\DataFieldWidgetInterface;

/**
 * Plugin implementation of the 'image_image' widget.
 *
 * @FieldWidget(
 *   id = "image_image",
 *   label = @Translation("Image"),
 *   field_types = {
 *     "image",
 *     "file",
 *     "entity_reference",
 *   },
 * )
 */
class ImageWidget implements DataFieldWidgetInterface {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    $options['preview_image_style'] = 'thumbnail';
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormElement(&$element, $item = NULL, $setting = []) {
    $fieldName = str_replace('field_', '', $element['#field_name']);
    $element['#upload_location'] = 'public://' . $fieldName . '/';
    if (!empty($element["#default_value"]) && !is_array($element["#default_value"])) {
      $element["#default_value"] = [$element["#default_value"]];
    }
    if (!empty($element["#field_settings"]["file_directory"])) {
      $element['#upload_location'] = 'public://' . $element["#field_settings"]["file_directory"] . '/';
    }

    $element["#type"] = 'managed_file';
    $element["#upload_validators"] = [
      'file_validate_extensions' => ['gif png jpg jpeg'],
    ];
    if (!empty($setting["preview_image_style"])) {
      $preview = $setting["preview_image_style"];
      $element['#theme'] = 'image_widget';
      $element['#preview_image_style'] = $preview ?? self::defaultSettings()['preview_image_style'];
    }
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $widget_settings = $form['#settings'];
    return [
      'preview_image_style' => [
        '#title' => $this->t('Preview image style'),
        '#type' => 'select',
        '#options' => image_style_options(FALSE),
        '#empty_option' => '<' . $this->t('no preview') . '>',
        '#default_value' => $widget_settings['preview_image_style'] ?? self::defaultSettings()['preview_image_style'],
        '#description' => $this->t('The preview image will be shown while editing the content.'),
      ],
    ];

  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary($settings = []) {
    $summary = [];
    $settings += self::defaultSettings();
    $summary[] = $this->t('Image style: @preview', ['@preview' => $settings['preview_image_style']]);
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues($value, array $form, FormStateInterface $form_state) {
    $entityType = $form["#field_settings"]["entity_reference_type"];
    $checkEntityFile = in_array($entityType, ['file', 'image']);
    if ($checkEntityFile && is_array($value)) {
      return current($value);
    }
  }

}
