<?php

namespace Drupal\datafield\Plugin\DataField\FieldWidget;

use Drupal\Core\Field\FieldFilteredMarkup;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\datafield\Plugin\DataFieldWidgetInterface;

/**
 * Plugin implementation of the 'options_buttons' widget.
 *
 * @FieldWidget(
 *   id = "options_buttons",
 *   label = @Translation("Check boxes/radio buttons"),
 *   field_types = {
 *     "entity_reference",
 *   }
 * )
 */
class OptionsButtonsWidget implements DataFieldWidgetInterface {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function getFormElement(&$element, $item = NULL, $setting = []) {
    $element['#type'] = 'radios';
    $optionsView = $element['#selection_settings']['options_view'] ?? [];
    $options = $this->getOptions($optionsView);
    $element['#options'] = $options;
  }

  /**
   * Returns the array of options for the widget.
   *
   * {@inheritdoc}
   */
  protected function getOptions($selection_options) {
    $selectionManager = \Drupal::service('plugin.manager.entity_reference_selection');
    $handler = $selectionManager->getInstance($selection_options);
    $options = $handler->getReferenceableEntities();
    if (!empty($options)) {
      $options = reset($options);
    }
    $entity = $selection_options['entity'];
    $context = [
      'entity' => $entity,
      'options' => $selection_options,
    ];
    \Drupal::service('module_handler')->alter('options_list', $options, $context);
    array_walk_recursive($options, [$this, 'sanitizeLabel']);
    return $options;
  }

  /**
   * Sanitizes a string label to display as an option.
   *
   * @param string $label
   *   The label to sanitize.
   */
  protected function sanitizeLabel(&$label) {
    // Allow a limited set of HTML tags.
    $label = FieldFilteredMarkup::create($label);
  }

}
