<?php

namespace Drupal\datafield\Plugin\DataField\FieldWidget;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\datafield\Plugin\DataFieldWidgetInterface;

/**
 * Plugin implementation of the 'range' widget.
 *
 * @FieldWidget(
 *   id = "range",
 *   label = @Translation("Range fields"),
 *   field_types = {
 *     "integer",
 *     "float",
 *     "decimal"
 *   }
 * )
 */
class RangeWidget implements DataFieldWidgetInterface {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function getFormElement(&$element, $item = NULL, $setting = []) {
    $element['#step'] = 1;
    if (!empty($setting['min'])) {
      $element['#min'] = $setting['min'];
    }
    if (!empty($setting['max'])) {
      $element['#max'] = $setting['max'];
    }
    if ($setting["type"] == 'numeric') {
      $element['#step'] = 0.1;
      if (!empty($setting['scale'])) {
        $setting['#step'] = pow(0.1, $setting['scale']);
      }
    }
    elseif ($setting["type"] == 'float') {
      $element['#step'] = 'any';
    }
    if (!empty($element["#field_settings"]["list"])) {
      $idDatalist = $element['#field_name'] . '-' . $element['#machine_name'];
      $element['#attributes']['list'] = $idDatalist;
      $element['#attributes']['class'][] = 'datalistfield';
      $element['#attached']['drupalSettings']['datalistfield'][$idDatalist] = $element["#field_settings"]["allowed_values"];
      $element['#attached']['library'][] = 'datafield/datalistfield';
    }
  }

}
